@@ -1,16 +1,18 @@
 # -*- coding: utf-8 -*-
-# ＵＴＦ－８
-import sys, traceback
-from PySide2.QtCore import QThread, Signal
+# FlashGBX
+# Author: Lesserkuma (github.com/lesserkuma)
 
-class DataTransfer(QThread):
+import sys, traceback
+import PySide2
+
+class DataTransfer(PySide2.QtCore.QThread):
 	CONFIG = None
 	FINISHED = False
 	
-	updateProgress = Signal(object)
+	updateProgress = PySide2.QtCore.Signal(object)
 
 	def __init__(self, config=None):
-		QThread.__init__(self)
+		PySide2.QtCore.QThread.__init__(self)
 		if config is not None:
 			self.CONFIG = config
 		self.FINISHED = False
